Model Type
Target Data
Predict Data
Clustered Index
Evaluation Metrics
R squared Mean Absolute Error Mean Absolute Percentage Error Root Mean Squared Error Scatter plot
Confusion Matrix Report (Accuracy/Precision/Recall/F1-score) * You can select individually Accuracy Precision Recall F1-scorev
Silhouette score
Feature Data

ARI (Adjusted Random Score) NMI (Normalized Mutual Information)
Target Data